package com.sf.oauth.enums;

import cn.hutool.core.util.StrUtil;
import lombok.AllArgsConstructor;
import lombok.Getter;

import java.util.Arrays;

/**
 * 用户性别
 *
 * @author zoukun
 */
@Getter
@AllArgsConstructor
public enum AuthUserGender {
    /**
     * MALE/FAMALE为正常值，通过{@link AuthUserGender#getRealGender(String)}方法获取真实的性别
     * UNKNOWN为容错值，部分平台不会返回用户性别，为了方便统一，使用UNKNOWN标记所有未知或不可测的用户性别信息
     */
    MALE("0", "男"),
    FEMALE("1", "女"),
    UNKNOWN("2", "未知");

    private String code;
    private String desc;

    /**
     * 获取用户的实际性别，常规网站
     *
     * @param originalGender 用户第三方标注的原始性别
     * @return 用户性别
     */
    public static AuthUserGender getRealGender(String originalGender) {
        if (null == originalGender || UNKNOWN.getCode().equals(originalGender)) {
            return UNKNOWN;
        }
        String[] males = {"m", "男", "0", "male"};
        if (Arrays.asList(males).contains(originalGender.toLowerCase())) {
            return MALE;
        }
        return FEMALE;
    }

}
